==> cdk_2.3.orig.tar.gz: cdk-cdk-2.3/base/interfaces/src/main/java/org/openscience/cdk/interfaces/IMapping.java <==
/* Copyright (C) 2006-2007  Kai Hartmann <kaihartmann@users.sf.net>
 *
 * Contact: cdk-devel@lists.sourceforge.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 */
package org.openscience.cdk.interfaces;

/**
 * Represents a mapping of two atoms.
 *
 * @cdk.module  interfaces
 * @cdk.githash
 * @author      kaihartmann
 * @cdk.created 2006-02-15
 */
public interface IMapping extends IChemObject {

    /**
     * Returns an {@link Iterable} to the two IChemObjects.
     *
     * @return An {@link Iterable} to two IChemObjects that define the mapping
     */
    public Iterable<IChemObject> relatedChemObjects();

    /**
     * Retrieve the first or second of the related IChemObjects.
     *
     * @param   pos  The position of the IChemObject.
     * @return  The IChemObject to retrieve.
     */
    public IChemObject getChemObject(int pos);

}

==> cdk_2.8.orig.tar.gz: cdk-cdk-2.8/base/interfaces/src/main/java/org/openscience/cdk/interfaces/IMapping.java <==
/* Copyright (C) 2006-2007  Kai Hartmann <kaihartmann@users.sf.net>
 *
 * Contact: cdk-devel@lists.sourceforge.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 */
package org.openscience.cdk.interfaces;

/**
 * Represents a mapping of two atoms.
 *
 * @cdk.module  interfaces
 * @cdk.githash
 * @author      kaihartmann
 * @cdk.created 2006-02-15
 */
public interface IMapping extends IChemObject {

    /**
     * Returns an {@link Iterable} to the two IChemObjects.
     *
     * @return An {@link Iterable} to two IChemObjects that define the mapping
     */
    Iterable<IChemObject> relatedChemObjects();

    /**
     * Retrieve the first or second of the related IChemObjects.
     *
     * @param   pos  The position of the IChemObject.
     * @return  The IChemObject to retrieve.
     */
    IChemObject getChemObject(int pos);

}
